# C/CUDA Sources (tide.csrc)

This section describes the native kernels and build configuration in `src/tide/csrc`.
TODO: Add build notes and call signatures for exported kernels.

## Key Files
- CMakelists.txt
- maxwell.c
- maxwell.cu
- storage_utils.c
- storage_utils.cu
- common_cpu.h
- common_gpu.h
- staggered_grid.h
- storage_utils.h
